import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/**
 * 异步选择组件
 */
import React, { useState, useEffect } from 'react';
import { Spin, message, Select } from 'antd';
import { fetch } from '../../../common/api';
import { log } from '../../../common/tool';
var Option = Select.Option; // 封装组件

var AjaxSelect = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var isOpen = React.useRef(true);
  var ajaxSelectRef = React.useRef();
  ajaxSelectRef = ref;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      listData = _useState4[0],
      setListData = _useState4[1];

  useEffect(function () {
    handleGetList();
    return function () {
      isOpen.current = false;
    };
  }, []);

  var handleGetList = function handleGetList() {
    var apiPath = props.apiPath,
        apiData = props.apiData,
        apiMethod = props.apiMethod,
        listName = props.listName;
    setLoading(true);
    fetch(apiPath, apiData, apiMethod).then(function (data) {
      if (isOpen.current) {
        setLoading(false);
        setListData(data.data);
      }
    }).catch(function (err) {
      log.error(err);
      message.error("\u83B7\u53D6".concat(listName, "\u5931\u8D25:").concat(err.message));
    });
  };

  var handleChange = function handleChange(key) {
    var value = props.value,
        listValueKey = props.listValueKey,
        listNameKey = props.listNameKey,
        onChange = props.onChange;

    if (Array.isArray(value)) {
      if (!key) return onChange(['', '']);
      var label;
      listData.some(function (item) {
        if (item[listValueKey].toString() === key) {
          label = item[listNameKey];
          return true;
        }

        return false;
      });
      onChange([key, label]);
    } else {
      onChange(key || '');
    }
  };

  var value = props.value,
      listName = props.listName,
      listValueKey = props.listValueKey,
      listNameKey = props.listNameKey,
      disabled = props.disabled;
  var selectValue;

  if (Array.isArray(value)) {
    selectValue = value[0];
  } else {
    selectValue = value;
  }

  return /*#__PURE__*/React.createElement(Spin, {
    spinning: loading,
    className: "app-ajax-select"
  }, /*#__PURE__*/React.createElement(Select, {
    showSearch: true,
    optionFilterProp: "children",
    value: selectValue,
    onChange: handleChange,
    placeholder: "\u9009\u62E9".concat(listName),
    notFoundContent: "\u672A\u627E\u5230".concat(listName),
    allowClear: true,
    disabled: disabled,
    ref: ajaxSelectRef
  }, /*#__PURE__*/React.createElement(Option, {
    value: "",
    title: "\u9009\u62E9".concat(listName)
  }, "\u9009\u62E9", listName), listData.map(function (item, index) {
    return /*#__PURE__*/React.createElement(Option, {
      key: index,
      value: item[listValueKey].toString(),
      title: item[listNameKey]
    }, item[listNameKey]);
  })));
});
export default AjaxSelect;