import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/**
 * 通用表格
 */
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import { Table, message, Spin } from 'antd';
import { fetch } from '../../../common/api';
import { getPageData, isObjEmpty, filterEmptyData } from '../../../common/tool';

var CommonTable = function CommonTable(props) {
  var isOpen = React.useRef(true);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = useState({
    content: []
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      tableData = _useState4[0],
      setTableData = _useState4[1];

  useEffect(function () {
    handleGetData({
      page: 1,
      pageSize: 10
    });
    return function () {
      isOpen.current = false;
    };
  }, []);

  var handleGetData = function handleGetData(queryData) {
    var apiPath = props.apiPath,
        apiData = props.apiData,
        apiMethod = props.apiMethod;
    setLoading(true);
    var sendData = filterEmptyData(_objectSpread(_objectSpread({}, apiData), queryData));
    fetch(apiPath, sendData, apiMethod).then(function (data) {
      // 判断如果卸载,则不再设置数据
      if (!data.data || !data.data.content) data.data.content = [];
      data.data.content.map(function (item, inx) {
        item.key = inx;
      });

      if (isOpen.current) {
        setLoading(false);
        setTableData(data.data);
      }
    }).catch(function (err) {
      setLoading(false);
      message.error("\u83B7\u53D6\u6570\u636E\u5931\u8D25:".concat(err.message));
    });
  };

  var handleChangePage = function handleChangePage(page, filters, sorter) {
    var sortType = props.sortType;
    var orders = {};

    if (!isObjEmpty(sorter)) {
      sortType.map(function (item) {
        if (item.text == sorter.columnKey) {
          orders = {
            sortType: item.value,
            isDesc: sorter.order === 'descend' ? 1 : 0
          };
        }
      });
    }

    handleGetData(_objectSpread({
      page: page.current,
      pageSize: page.pageSize
    }, orders));
  };

  var tableTitle = props.tableTitle,
      columns = props.columns,
      isShowPagination = props.isShowPagination,
      isShowBordered = props.isShowBordered,
      rightLink = props.rightLink,
      rightLinkTitle = props.rightLinkTitle,
      pageSizeOptions = props.pageSizeOptions,
      rowKeyFun = props.rowKeyFun,
      scroll = props.scroll;
  var pageData;

  if (isShowPagination && pageSizeOptions) {
    pageData = _objectSpread(_objectSpread({}, getPageData(tableData)), {}, {
      pageSizeOptions: pageSizeOptions
    });
  } else pageData = _objectSpread({}, getPageData(tableData));

  return /*#__PURE__*/React.createElement(Spin, {
    spinning: loading
  }, tableTitle ? /*#__PURE__*/React.createElement("h3", null, tableTitle, rightLink ? /*#__PURE__*/React.createElement("a", {
    className: "right-link pull-right",
    href: rightLink,
    target: "_blank",
    rel: "noopener noreferrer"
  }, rightLinkTitle) : null) : null, /*#__PURE__*/React.createElement(Table, {
    columns: columns,
    bordered: isShowBordered,
    pagination: isShowPagination ? pageData : false,
    dataSource: tableData.content,
    onChange: handleChangePage,
    rowKey: rowKeyFun,
    scroll: scroll
  }));
};

CommonTable.propTypes = {
  rightLink: PropTypes.string,
  rightLinkTitle: PropTypes.string,
  tableTitle: PropTypes.string,
  columns: PropTypes.array.isRequired,
  isShowBordered: PropTypes.bool,
  isShowPagination: PropTypes.bool,
  apiPath: PropTypes.string.isRequired,
  apiData: PropTypes.object,
  apiMethod: PropTypes.string,
  sortType: PropTypes.array,
  pageSizeOptions: PropTypes.array,
  rowKeyFun: PropTypes.func,
  scroll: PropTypes.object
};
CommonTable.defaultProps = {
  isShowBordered: true
};
export default CommonTable;