"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _antd = require("antd");

var _api = require("../../../common/api");

var _tool = require("../../../common/tool");

/**
 * 动态数据异步选择组件
 */
var Option = _antd.Select.Option; // 封装组件

var DynamicAjaxSelect = /*#__PURE__*/_react.default.forwardRef(function (props, ref) {
  var isFirst = _react.default.useRef(true);

  var prevApiData = _react.default.useRef(props.apiData);

  var dynamicAjaxSelectRef = _react.default.useRef();

  dynamicAjaxSelectRef = ref;

  var _useState = (0, _react.useState)(false),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = (0, _react.useState)([]),
      _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
      listData = _useState4[0],
      setListData = _useState4[1];

  (0, _react.useEffect)(function () {
    var result = (0, _tool.isEqual)(prevApiData.current, props.apiData);

    if (isFirst.current && props.firstShowAll) {
      // 首次加载获取数据
      handleGetList();
    }

    if (!result) {
      // 参数不一样才重新获取数据
      handleGetList();
    }

    return function () {
      isFirst.current = false;
      prevApiData.current = props.apiData;
    };
  }, [props.apiData]);

  var handleGetList = function handleGetList() {
    var apiPath = props.apiPath,
        apiData = props.apiData,
        apiMethod = props.apiMethod,
        listName = props.listName,
        onChange = props.onChange,
        value = props.value; // 当为空时,不显示

    if (!isFirst.current && (0, _tool.isObjEmpty)(apiData)) {
      // 重置选择
      if (Array.isArray(value)) {
        onChange([]);
      } else {
        if (value) onChange({});
      } // 重置数据


      setListData([]);
      return;
    }

    setLoading(true);
    (0, _api.fetch)(apiPath, apiData, apiMethod).then(function (data) {
      setListData(data.data);
    }).catch(function (err) {
      _tool.log.error(err);

      _antd.message.error("\u83B7\u53D6".concat(listName, "\u5931\u8D25:").concat(err.message));
    }).finally(function () {
      setLoading(false);
    });
  };

  var handleChange = function handleChange(key) {
    var value = props.value,
        listValueKey = props.listValueKey,
        listNameKey = props.listNameKey,
        onChange = props.onChange;

    if (Array.isArray(value)) {
      if (!key) return onChange(['', '']);
      var label;
      listData.some(function (item) {
        if (item[listValueKey].toString() === key) {
          label = item[listNameKey];
          return true;
        } else return false;
      });
      onChange([key, label]);
    } else {
      var groupId;
      listData.some(function (item) {
        if (item[listValueKey].toString() === key || item[listValueKey].toString() === value) {
          groupId = item.chanceGroup.toString();
          return true;
        } else return false;
      });
      onChange(key ? (0, _defineProperty2.default)({
        groupId: groupId
      }, listValueKey, key) : (0, _defineProperty2.default)({
        groupId: groupId
      }, listValueKey, null));
    }
  };

  var value = props.value,
      listName = props.listName,
      listValueKey = props.listValueKey,
      listNameKey = props.listNameKey,
      disabled = props.disabled;
  var selectValue;

  if (Array.isArray(value)) {
    selectValue = value[0];
  } else {
    selectValue = value;
  }

  return /*#__PURE__*/_react.default.createElement(_antd.Spin, {
    spinning: loading,
    className: "app-dynamic-ajax-select"
  }, /*#__PURE__*/_react.default.createElement(_antd.Select, {
    showSearch: true,
    optionFilterProp: "children",
    value: selectValue,
    onChange: handleChange,
    placeholder: "\u9009\u62E9".concat(listName),
    notFoundContent: "\u672A\u627E\u5230".concat(listName),
    allowClear: true,
    disabled: disabled,
    ref: dynamicAjaxSelectRef
  }, /*#__PURE__*/_react.default.createElement(Option, {
    value: "",
    title: "\u9009\u62E9".concat(listName)
  }, "\u9009\u62E9", listName), listData.map(function (item, index) {
    return /*#__PURE__*/_react.default.createElement(Option, {
      key: index,
      value: item[listValueKey].toString(),
      title: item[listNameKey]
    }, item[listNameKey]);
  })));
});

var _default = DynamicAjaxSelect;
exports.default = _default;