"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.ZoomGroup = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _dragble_modal = _interopRequireDefault(require("./dragble_modal"));

/**
 * 可拖拽，可放大缩小的图片组件
 */
var ZoomImage = function ZoomImage(props) {
  var _useState = (0, _react.useState)(false),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      dragging = _useState2[0],
      setDragging = _useState2[1];

  var _useState3 = (0, _react.useState)(null),
      _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
      startX = _useState4[0],
      setStartX = _useState4[1];

  var _useState5 = (0, _react.useState)(null),
      _useState6 = (0, _slicedToArray2.default)(_useState5, 2),
      startY = _useState6[0],
      setStartY = _useState6[1];

  var _useState7 = (0, _react.useState)(null),
      _useState8 = (0, _slicedToArray2.default)(_useState7, 2),
      endX = _useState8[0],
      setEndX = _useState8[1];

  var _useState9 = (0, _react.useState)(null),
      _useState10 = (0, _slicedToArray2.default)(_useState9, 2),
      endY = _useState10[0],
      setEndY = _useState10[1];

  var _useState11 = (0, _react.useState)(0),
      _useState12 = (0, _slicedToArray2.default)(_useState11, 2),
      recordX = _useState12[0],
      setRecordX = _useState12[1];

  var _useState13 = (0, _react.useState)(0),
      _useState14 = (0, _slicedToArray2.default)(_useState13, 2),
      recordY = _useState14[0],
      setRecordY = _useState14[1];

  var _useState15 = (0, _react.useState)(null),
      _useState16 = (0, _slicedToArray2.default)(_useState15, 2),
      zoomPrecent = _useState16[0],
      setzoomPrecent = _useState16[1];

  var handleImageWheel = function handleImageWheel(e) {
    var body = document.getElementsByTagName('body')[0];
    body.style.overflow = 'hidden';
    var zoomImage = document.getElementById('zoomImage');
    var zoom = parseInt(zoomImage.getAttribute('zoom'), 10) || 100;
    zoom += e.deltaY / 10;

    if (zoom > 100 && zoom < 300) {
      setzoomPrecent(zoom / 100);
      zoomImage.style.transform = "scale(".concat(zoomPrecent, ", ").concat(zoomPrecent, ")");
      zoomImage.setAttribute('zoom', "".concat(zoom, "%"));
    } else {
      return false;
    }
  };

  var handleMouseDown = function handleMouseDown(e) {
    e.stopPropagation();
    e.preventDefault();
    setStartX(e.clientX - recordX * 2);
    setStartY(e.clientX - recordX * 2);
    setDragging(true);
  };

  var handleMouseMove = function handleMouseMove(e) {
    e.stopPropagation();
    e.preventDefault();

    if (dragging) {
      var zoomImage = document.getElementById('zoomImage');
      setEndX(e.clientX);
      setEndY(e.clientY); //  控制拖拽灵敏度

      setRecordX((endX - startX) / 2);
      setRecordY((endY - startY) / 2);
      zoomImage.style.transform = "scale(".concat(zoomPrecent, ", ").concat(zoomPrecent, ") translate(").concat(recordX, "px, ").concat(recordY, "px)");
    }
  };

  var handleMouseUpAndLeave = function handleMouseUpAndLeave(e) {
    e.stopPropagation();
    e.preventDefault();
    setDragging(false);
    setStartX(null);
    setStartY(null);
    setEndX(null);
    setEndY(null);
  };

  var handleOnCancel = function handleOnCancel() {
    var onCancel = props.onCancel;
    var body = document.getElementsByTagName('body')[0];
    body.style.overflow = '';
    onCancel();
  };

  var path = props.path;
  return /*#__PURE__*/_react.default.createElement(_dragble_modal.default, {
    onCancel: handleOnCancel,
    title: "\u56FE\u7247\u9884\u89C8"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "app-file-preview-image"
  }, /*#__PURE__*/_react.default.createElement("img", {
    id: "zoomImage",
    src: path,
    onWheel: handleImageWheel,
    onMouseDown: handleMouseDown,
    onMouseMove: handleMouseMove,
    onMouseUp: handleMouseUpAndLeave,
    onMouseLeave: handleMouseUpAndLeave
  })));
};

var ZoomView = function ZoomView(props) {
  var _useState17 = (0, _react.useState)(false),
      _useState18 = (0, _slicedToArray2.default)(_useState17, 2),
      showModal = _useState18[0],
      setShowModal = _useState18[1];

  var path = props.path;

  var handleCloseModal = function handleCloseModal() {
    setShowModal(false);
  };

  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, /*#__PURE__*/_react.default.createElement("span", {
    onClick: function onClick(e) {
      e.preventDefault();
      setShowModal(true);
    }
  }, /*#__PURE__*/_react.default.createElement("img", {
    src: path
  })), showModal ? /*#__PURE__*/_react.default.createElement(ZoomImage, {
    path: path,
    onCancel: handleCloseModal
  }) : null);
};

var ZoomGroup = function ZoomGroup(props) {
  var path = props.path;
  var list = [];

  if (Array.isArray(path)) {
    list = path;
  } else {
    list = [path];
  }

  return /*#__PURE__*/_react.default.createElement("div", {
    className: "app-file-upload"
  }, /*#__PURE__*/_react.default.createElement("ul", {
    className: "app-file-upload-preview no-list-style"
  }, list.map(function (item, index) {
    return /*#__PURE__*/_react.default.createElement("li", {
      key: index,
      className: "file-wrapper super-file-wrapper"
    }, /*#__PURE__*/_react.default.createElement(ZoomView, {
      key: index,
      path: item
    }));
  })));
};

exports.ZoomGroup = ZoomGroup;
var _default = ZoomImage;
exports.default = _default;